@@ -238,7 +238,7 @@ class NamedTupleBuilder(NamedTupleBuilderBase):
     return _Args(
         name=name, field_names=field_names, defaults=defaults, rename=rename)
 
-  def call(self, node, _, args):
+  def call(self, node, _, args, alias_map=None):
     """Creates a namedtuple class definition."""
     # If we can't extract the arguments, we take the easy way out and return Any
     try:
@@ -320,7 +320,7 @@ class NamedTupleFuncBuilder(NamedTupleBuilderBase):
 
     return _Args(name=cls_name, field_names=names, field_types=types)
 
-  def call(self, node, _, args):
+  def call(self, node, _, args, alias_map=None):
     try:
       args, props = self.process_args(node, args)
     except _ArgsError:
@@ -710,11 +710,8 @@ def _build_namedtuple(props, node, ctx):
   cls_dict = abstract.Dict(ctx)
   cls_dict.update(node, members)
 
-  if ctx.options.strict_namedtuple_checks:
-    # Enforces type checking like Tuple[...]
-    superclass_of_new_type = heterogeneous_tuple_type.to_variable(node)
-  else:
-    superclass_of_new_type = ctx.convert.tuple_type.to_variable(node)
+  # Enforces type checking like Tuple[...]
+  superclass_of_new_type = heterogeneous_tuple_type.to_variable(node)
   if props.bases:
     final_bases = []
     for base in props.bases:
