@@ -608,14 +608,27 @@ class _GeneratePytdVisitor(visitor.BaseVisitor):
     node.args = [name.s]
 
   def _convert_typed_dict_args(self, node: ast3.Call):
-    # TODO(b/157603915): new_typed_dict currently doesn't do anything with the
-    # args, so we don't bother converting them fully.
     msg = "Wrong args: expected TypedDict(name, {field: type, ...})"
     if len(node.args) != 2:
       raise ParseError(msg)
     name, fields = node.args
     if not (isinstance(name, ast3.Str) and isinstance(fields, ast3.Dict)):
       raise ParseError(msg)
+    name_value = name.s
+    fields_value = {}
+    for k, v in zip(fields.keys, fields.values):
+      if (hasattr(ast3, "Constant") and isinstance(k, ast3.Constant) and
+          isinstance(k.value, str)):  # Python 3.8+
+        k_value = k.value
+      elif isinstance(k, ast3.Str):  # Python 3.7
+        k_value = k.s
+      else:
+        raise ParseError(msg)
+      v_pytd = self.convert_node(v)
+      if not isinstance(v_pytd, pytd.Type):
+        raise ParseError(msg)
+      fields_value[k_value] = v_pytd
+    node.args = [name_value, fields_value]
 
   def enter_Call(self, node):
     # Some function arguments need to be converted from strings to types when
